==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>이미지 보기도구</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>이미지 보기도구는 인기있는 인터페이스와 원활한 성능을 갖춘 이미지보기 도구입니다.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>이미지</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>기본 정보</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>상세 정보</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>이 파일에는 여러 페이지가 포함되어 있으므로, Evince를 사용하여 모든 페이지를 보십시오.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>디렉토리 열기</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>이미지를 볼 수 있는 권한이 없습니다</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>형식</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>수정된 날짜</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>치수</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>파일 크기</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>캡처된 날짜</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>노출 모드</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>노출 프로그램</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>노출 시간</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>플래시</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>조리개</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>초점 거리</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>최대 조리개</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>미터링 모드</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>화이트 밸런스</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>플래시 보정</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>렌즈 모델</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>색상공간</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>카메라 모델</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>치수</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>태그</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>크기 조정 없음</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>이미지에 페이지 맞춤</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>페이지에 이미지 맞춤</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>다음으로 확장:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>밀리미터</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>센티미터</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>인치</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>이미지 위치</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>크기 조정</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>이미지 설정</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>이미지 설정</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>블라인드</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>전환도구</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>슬라이딩</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>링</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>새 이름 입력</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>디렉토리 선택</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>이 디렉토리는 동기화 할 수 없습니다</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>폴더 추가</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>동기화 디렉토리 관리</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>디렉토리 목록이 비어 있습니다</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>동기화 취소</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>이미지</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>장치가 제거되었습니다</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>이 디렉토리는 더 이상 존재하지 않습니다</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>계산중 ...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>이미지 보는 중</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>앨범</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 표시</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>표시 종료</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>엘범에서 제거</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>바탕화면으로 설정</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리도구에 표시</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>이전 화면</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>다음 화면</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 변경</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>전체화면 종료</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>확대</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>축소</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>새 바로가기를 입력하십시오</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>단축키</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>사진 보기</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>앨범</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>기본값 복원</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 표시</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>표시 종료</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>엘범에서 제거</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>바탕화면으로 설정</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리도구에 표시</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 변경</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시중지</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>슬라이드 설정</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>효과 전환</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>지속시간</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>지속시간 전환</translation>
    </message>
    <message>
        <source>second</source>
        <translation>초</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>내 즐겨찾기</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 크기</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>창에 맞춤</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>뒤로</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>이미지 관리</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>내 즐겨찾기</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 크기</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>창에 맞춤</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>이미지 열기</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>슬라이드 설정</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>효과</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>지속시간</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>단축키</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>앨범</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>연대순</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>앨범에 추가</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>새 앨범에 추가</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>전체화면 종료</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 표시</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>엘범에서 제거</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>탐색 창 표시</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>탐색 창 숨기기</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>바탕화면으로 설정</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리도구에 표시</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>이미지 열기</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>모든 이미지</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 변경</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>그리기</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.3.orig.tar.xz: deepin-image-viewer-5.9.3/src/translations/deepin-image-viewer_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>이미지 열기</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>이미지 보는 중</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>전체화면 종료</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 표시</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 변경</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>바탕화면으로 설정</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리도구에 표시</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>확대</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>축소</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>이미지 보기도구</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>이미지 보기도구는 인기있는 인터페이스와 원활한 성능을 갖춘 이미지보기 도구입니다.</translation>
    </message>
</context>
</TS>
